// Import required modules from D3
import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  line,
  max
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

//Creating Line graph

const render = data => { 
  
// Mark X axis data   
  const xValue = d => d.Year; 
  const xAxisLabel = 'Year';
  
// Mark Y axis data 
  const yValue = d => d.Sales;
  const yAxisLabel = 'Sales';
  
  const margin = { top: 10, right: 40, bottom: 120, left: 150 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top-30 - margin.bottom-20;
  
  // determine the Scale for X axis with year values
  const xScale = scaleTime()
    .domain(extent(data, xValue)) 
    .range([0, innerWidth]) 
    .nice(); //round values out
  
// determine the Scale for Y axis with population values
  const yScale = scaleLinear()
    .domain([0, max(data, yValue )])
    .range([innerHeight, 0])
    .nice();

// postion the svg   
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
 // Assigning values to x axis  
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(20);
  
 // Assigning values to y axis  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10)
  ;
  	
  //Appending Y axis label
  const yAxisG = g.append('g').call(yAxis);
  	yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -120)
      .attr('x', -innerHeight / 3)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .text(yAxisLabel);
  //Appending X axis label
  const xAxisG = g.append('g').call(xAxis)
    	.attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 70)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);

// Drawing a line and adding it to svg 
  
  const lineGenerator = line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue(d)));
  
  g.append('path')
  	.attr('class', 'line_path')
  	.attr('d', lineGenerator(data))
};

// Loading and Parsing CSV data
csv('https://gist.githubusercontent.com/bhargavarathod/25272cec91ffba2f645cfb192bbf48e1/raw/7c6ab82db3379a1df54526126026eaf86950d12a/sales.csv')
  .then(data => {
    data.forEach(d => {
      d.Sales = +d.Sales;
//Formatting to retrieve year from the date
       d.Year = new Date(d.Year)
    });
    render(data);
  });